from pyramid.view import view_config, view_defaults
from pyramid.config import Configurator
from pyramid_beaker import session_factory_from_settings
from pyramid.renderers import JSONP

WORKFLOWS = [{'id': 1, 'name': 'foo', 'files': {'file.txt': {'id': 1, 'name': 'file.txt', 'content': 'Hello, world!'}}}]


def lookup_workflow(request):
    return WORKFLOWS[int(request.matchdict['id'])]


def lookup_file(request):
    return lookup_workflow(request)['files'][request.matchdict['filename']]


@view_defaults(route_name='workflows', renderer='json')
class WorkflowService:
    def __init__(self, request):
        self.request = request

    @view_config(request_method='GET')
    def list_workflows(self):
        return WORKFLOWS

    @view_config(request_method='POST')
    def create_workflow(self):
        WORKFLOWS.append(self.request.json_body)
        return True

    @view_config(request_method='GET', route_name='workflow')
    def get_workflow(self):
        return self.request.context

    @view_config(request_method='POST', route_name='submit_workflow')
    def submit_workflow(self):
        # submit the workflow for processing
        print(f"Submitting workflow {self.request.context['id']}")

    @view_config(request_method='POST', route_name='workflow_files')
    def add_file(self):
        # add a file to this workflow request
        print('Adding a file')

    @view_config(request_method='GET', route_name='workflow_files')
    def get_files(self):
        return self.request.context['files']

    @view_config(request_method='GET', route_name='workflow_file', accept='text/plain', renderer='string')
    def get_file_text(self):
        return self.request.context['content']

    @view_config(request_method='GET', route_name='workflow_file', accept='application/json')
    def get_file_json(self):
        return self.request.context


def main(global_config, **settings):
    # DB['SDM'] = scoped_session(sessionmaker(extension=ZopeTransactionExtension()))

    with Configurator(settings=settings) as config:
        session_factory = session_factory_from_settings(settings)
        config.set_session_factory(session_factory)
        config.add_renderer('jsonp', JSONP(param_name='callback'))

        config.add_route('workflows', '/workflows')
        config.add_route('workflow', '/workflows/{id}', factory=lookup_workflow)
        config.add_route('submit_workflow', '/workflows/{id}/submit', factory=lookup_workflow)
        config.add_route('workflow_files', '/workflows/{id}/files', factory=lookup_workflow)
        config.add_route('workflow_file', '/workflows/{id}/files/{filename}', factory=lookup_file)

        config.include('pyramid_beaker')
        config.scan('.')
        return config.make_wsgi_app()
